Gerbi’s CMS documentation — django-page-cms 2.0.0 documentation

# Gerbi’s CMS documentation

Welcome on the documentation of the simple multilingual Gerbi CMS (package name: django-page-cms). You track the latest changes to the code base on the github project page. To get more information about this CMS and its feature go to the Introduction section.

For a quick install:

    $ pip install django-page-cms[full]; gerbi --create mywebsite

For more complete installations instructions go to the Installation section. To get source code with git use:

    $ git clone git://github.com/batiste/django-page-cms.git django-page-cms

Build this documentation from cloned repo:

    $ pip install .[docs]
    $ python setup.py build_sphinx

## Table of content

- Introduction
  - Screenshot
  - Features
  - Dependencies & Compatibility
  - How to contribute
  - Report a bug
  - Internationalisation
- Contribute to Gerbi CMS
  - Write tests
  - Translations
- Placeholders template tag
  - Enable the placeholder tags
  - Detailed explanations on placeholder options
  - Image placeholder
  - File placeholder
  - Markdown placeholder
  - Contact placeholder
  - Create your own placeholder
  - Changing the widget of the common placeholder
  - List of placeholder widgets shipped with the CMS
- Installation
  - Evaluate quickly the application
  - Install dependencies by using pip
  - Add django-page-cms into your INSTALLED_APPS
  - Urls
  - Settings
- Display page’s content in templates
  - get_content
  - show_content
  - page_has_content
  - get_page
  - show_absolute_url
  - Delegate the page rendering to another application
  - Subclass the default view
- Inline page editing
- How to use the various navigation template tags
  - pages_menu
  - pages_dynamic_tree_menu
  - pages_sub_menu
  - pages_siblings_menu
  - pages_breadcrumb
  - load_pages
- Integrate with other applications
  - Delegate the rendering of a page to an application
  - Sitemaps
- Commands
  - Import and export content between diffent hosts using the API
  - Export pages content into translatable PO files
- List of all available settings
  - PAGE_TEMPLATES
  - PAGE_DEFAULT_TEMPLATE
  - PAGE_LANGUAGES
  - PAGE_DEFAULT_LANGUAGE
  - PAGE_LANGUAGE_MAPPING
  - PAGES_MEDIA_URL
  - PAGE_UNIQUE_SLUG_REQUIRED
  - PAGE_CONTENT_REVISION
  - SITE_ID
  - PAGE_USE_SITE_ID
  - PAGE_USE_LANGUAGE_PREFIX
  - PAGE_CONTENT_REVISION_EXCLUDE_LIST
  - PAGE_HIDE_ROOT_SLUG
  - PAGE_SHOW_START_DATE
  - PAGE_SHOW_END_DATE
  - PAGE_TAGGING
  - PAGE_TESTS_SAVE_SCREENSHOTS
  - PAGE_REDIRECT_OLD_SLUG
- Changelog
  - Release 2.0.0
  - Release 1.9.17
  - Release 1.9.15
  - Release 1.9.14
  - Release 1.9.13
  - Release 1.9.12
  - Release 1.9.11
  - Release 1.9.10
  - Release 1.9.9
  - Release 1.9.8
  - Release 1.9.7
  - Release 1.9.6
  - Release 1.9.5
  - Release 1.9.4
  - Release 1.9.3
  - Release 1.9.1
  - Release 1.9.0
  - Release 1.8.2
  - Release 1.8.1
  - Release 1.8.0
  - Release 1.6.2
  - Release 1.6.1
  - Release 1.6.0
  - Release 1.5.3
  - Release 1.5.2
  - Release 1.5.1
  - Release 1.5.0
  - Release 1.4.3
  - Release 1.4.2
  - Release 1.4.1
  - Release 1.4.0
  - Release 1.3.0
  - Release 1.2.1
  - Release 1.2.0
  - Release 1.1.3
  - Release 1.1.2
  - Release 1.1.1
  - Release 1.1.0
  - Release 1.0.9
  - Release 1.0.8
- Page CMS reference API
  - The application model
  - Placeholders
  - Template tags
  - Widgets
  - Page Model
  - Page Manager
  - Page view
  - Content Model
  - Content Manager
  - PageAlias Model
  - PageAlias Manager
  - Utils
  - Http

## Indices and tables

- Index
- Module Index
- Search Page